import {
  Datasource, Http, IDictionary, Loader, Metadata, IEventParam, Config, I18n,
} from '@zeedhi/core';
import {
  Button, CollapseCard, Date as ZdDate, Form, GridEditable, Select, TextInput, Modal, ModalService, Text,
} from '@zeedhi/common';
import { PmeMask } from '@/config';

export class Pme01400EfetivosController {
  public appController = Loader.getInstance('AppController');
  
  public modalController = Loader.getInstance('ModalController');
  
  public utilities = Loader.getInstance('Utilities');
  
  public gridEditController = Loader.getInstance('GridEditableController');
  
  public reportController = Loader.getInstance('ReportController');
  
  public editable = false;
  
  private dtProcessa = '';
  
  public modalRelatorios!: Modal;
  
  private modalConfigCard!: Modal;
  
  private nrlista = '';
  
  public get showFormEfetivos() {
    const gridEfetivos = Metadata.getInstance<GridEditable>('EFETIVOS_GRID');
    return gridEfetivos.datasource.currentRow.CDSERVFILI !== undefined;
  }
  
  get controlExportButton() {
    const gridEfetivos = Metadata.getInstance<GridEditable>('EFETIVOS_GRID');
    if (gridEfetivos.selectedRows.length === 0) return true;
    return false;
  }
  
  get controlAddButtonEfetivos() {
    const dtcardiapme = Metadata.getInstance<Select>('DTCARDIAPME');
    const unidade = Metadata.getInstance<Select>('UNIDADE');
    const tipocard = Metadata.getInstance<Select>('TIPOCARD');
    if (dtcardiapme.value && unidade.value && tipocard.value) return false;
    return true;
  }
  
  public addRow({ component }: IDictionary) {
    this.editable = true;
    const grid: GridEditable = this.utilities.returnGrid(component) as GridEditable;

    if (!this.gridEditController.newRow) {
      this.gridEditController.addRowSetFocusSecondPosition({ component: grid });
      if (!this.gridEditController.isInlineEditing) this.gridEditController.onInlineEdit({ component: grid });
    }
  }

  public cancelEditing({ component }: IDictionary) {
    this.editable = false;
    this.gridEditController.cancelEditing({ component });
  }
  
  public setDefaultValues() {
    const component = Metadata.getInstance<ZdDate>('DTCARDIAPME');
    this.utilities.getProcessDate().then((processDate: string) => {
      if (processDate !== '') {
        const diaSemana = this.returnDiaSemana(processDate);
        this.dtProcessa = processDate;
        component.value = processDate;
        Metadata.getInstance<TextInput>('DIASEMANA').value = diaSemana;
      }
    });
  }
  
  public reloadTelaEfetivos() {
    const formFiltro: Form = Metadata.getInstance<Form>('FILTRO');
    if (formFiltro.validate()) {
      const gridEfetivos = Metadata.getInstance<GridEditable>('EFETIVOS_GRID');
      gridEfetivos.datasource.get();
    }
  }
  
  public validaData(form: Form) {
    let valid = false;
    const row: IDictionary = form.value;
    const dataComponente = row.DTCARDIAPME;
    const dataProcessamento = this.dtProcessa;
    const fieldDiaSemana = Metadata.getInstance<TextInput>('DIASEMANA');
    const dtTipoCard = Metadata.getInstance<Select>('DTCARDIAPME');
    const gridEfetivos = Metadata.getInstance<GridEditable>('EFETIVOS_GRID');
    const gridClientes = Metadata.getInstance<GridEditable>('CLIENTES_GRID');
    fieldDiaSemana.value = this.returnDiaSemana(dataComponente);
    if (!this.utilities.dateIsValid(dataComponente, dataProcessamento)) {
      this.utilities.showAlert('alertError', 'pme::dataMenorIgualDtProcessa', 'red');
      dtTipoCard.value = '';
      fieldDiaSemana.value = '';
      if (gridEfetivos.editing) this.resetGrid(gridEfetivos);
      else gridEfetivos.datasource.data = [];
      this.setComensQt();
      
      if (gridClientes.editing) this.resetGrid(gridClientes);
      else gridClientes.datasource.data = [];
    } else valid = true;
    return valid;
  }
  
  public setFilterTpCard({ component }: IEventParam<Select>) {
    const filter = [
      {
        name: 'CDFILCENTPME',
        operator: '=',
        value: this.appController.getCdCentral(),
      },
      {
        name: 'CDTIPOCARD',
        operator: '=',
        value: null,
      },
    ];
    
    component.datasource.filter = filter;
    component.datasource.get();
  }
  
  public setFilterUnidade({ component }: IEventParam<Select>) {
    const tipoCard = Metadata.getInstance<Select>('TIPOCARD');
    const filter = [
      {
        name: 'CDFILCENTPME',
        operator: '=',
        value: this.appController.getCdCentral(),
      },
      {
        name: 'CDTIPOCARD',
        operator: '=',
        value: tipoCard.value,
      },
    ];
    
    component.datasource.filter = filter;
    component.datasource.get();
  }
  
  public clearFields({ component }: IEventParam<Select>) {
    const gridEfetivos = Metadata.getInstance<GridEditable>('EFETIVOS_GRID');
    const gridClientes = Metadata.getInstance<GridEditable>('CLIENTES_GRID');
    const unidade = Metadata.getInstance<Select>('UNIDADE');

    if (component.name === 'TIPOCARD') {
      unidade.setValue('');
      gridEfetivos.datasource.data = [];
      gridClientes.datasource.data = [];
    } else unidade.setValue('');
  }
  
  // Grid Efetivos
  
  public isDetailsActionVisible({ row }: IDictionary) {
    return row.IDSOMADIF === 'S';
  }
  
  public alertButtonAction() {
    this.utilities.showAlert('alertError', 'pme::qtdTotalEfetClie', 'warning');
  }
  
  public setFilterGridEfetivos() {
    const filtro = Metadata.getInstance<Form>('FILTRO');
    const unidade = Metadata.getInstance<Select>('UNIDADE');
    const dtTipoCard = Metadata.getInstance<Select>('DTCARDIAPME');
    const tipoCard = Metadata.getInstance<Select>('TIPOCARD');
    const gridServEfet = Metadata.getInstance<GridEditable>('EFETIVOS_GRID');
    const gridClientes = Metadata.getInstance<GridEditable>('CLIENTES_GRID');
    const row = filtro.value;
    if (this.validaData(filtro)) {
      if (unidade.value) {
        if (gridServEfet.editing) this.resetGrid(gridServEfet, false);
        if (gridClientes.editing) this.resetGrid(gridClientes, false);
        
        Http.post('/verificaExisteCardapioFiltro', { requestType: 'Row', row }).then((response) => {
          if (response.data.dataset.result.length !== 0) {
            const filter = [
              {
                name: 'CDFILCENTPME',
                operator: '=',
                value: this.appController.getCdCentral(),
              },
              {
                name: 'CDFILIAL',
                operator: '=',
                value: unidade.value.CDFILIAL ? unidade.value.CDFILIAL : '',
              },
              {
                name: 'DTCARDIAPME',
                operator: '=',
                value: dtTipoCard.value,
              },
              {
                name: 'DTEFETCLIE',
                operator: '=',
                value: dtTipoCard.value,
              },
              {
                name: 'CDTIPOCARD',
                operator: '=',
                value: tipoCard.value,
              },
            ];
            gridServEfet.datasource.filter = filter;
            gridServEfet.datasource.get().then(() => {
              this.setComensQt();
            });
          } else {
            this.utilities.showAlert('alertError', 'pme::dataForaPeridoCard', 'red');
            unidade.setValue('');
            if (gridServEfet.editing) this.resetGrid(gridServEfet);
            else gridServEfet.datasource.data = [];
            this.setComensQt();
          }
        });
      } else {
        if (gridServEfet.editing) this.resetGrid(gridServEfet);
        this.setComensQt();
        
        if (gridClientes.editing) this.resetGrid(gridClientes);
      }
    }
  }
  
  private resetGrid(grid: GridEditable, clearData = true) {
    this.gridEditController.newRow = false;
    grid.cancelEditedRows();
    this.gridEditController.onInlineEdit({ component: grid });
    if (clearData) {
      grid.datasource.filter = [];
      grid.datasource.data = [];
    }
  }
  
  private setComensQt() {
    const gridServEfet = Metadata.getInstance<GridEditable>('EFETIVOS_GRID');
    const dados = gridServEfet.datasource.data;
    if (dados.length > 0) {
      gridServEfet.datasource.currentRow = dados[0];
      Metadata.getInstance<Text>('QTCLIESTCPME').text = gridServEfet.datasource.currentRow.QTCLIESTCPME;
      Metadata.getInstance<Text>('QTFUNESTCPME').text = gridServEfet.datasource.currentRow.QTFUNESTCPME;
      Metadata.getInstance<Text>('QTDOAESTCPME').text = gridServEfet.datasource.currentRow.QTDOAESTCPME;
      Metadata.getInstance<Text>('QTCOMESTCPME').text = gridServEfet.datasource.currentRow.QTCOMESTCPME;
    } else {
      Metadata.getInstance<Text>('QTCLIESTCPME').text = '';
      Metadata.getInstance<Text>('QTFUNESTCPME').text = '';
      Metadata.getInstance<Text>('QTDOAESTCPME').text = '';
      Metadata.getInstance<Text>('QTCOMESTCPME').text = '';
    }
  }
  
  public saveServiceEfetivos({ component }: IDictionary) {
    const gridEfetivos: GridEditable = this.utilities.returnGrid(component) as GridEditable;
    const dados = gridEfetivos.datasource.data;
    const filtro = Metadata.getInstance<Form>('FILTRO');
    const rows = gridEfetivos.getEditedRows();
    
    if (filtro.validate() && rows.length > 0) {
      rows.forEach((item) => {
        item.CDFILCENTPME = this.appController.getCdCentral();
        item.CDFILIAL = filtro.value.UNIDADE.CDFILIAL;
        item.DTCARDIAPME = filtro.value.DTCARDIAPME;
        item.CDTIPOCARD = filtro.value.TIPOCARD;
        if (item.__is_new) item.NRCARDPME = dados.length > 1 ? dados[1].NRCARDPME : null;
      });
      
      if (gridEfetivos) gridEfetivos.datasource.loading = true;
      Http.post('/saveServEfetivos', { requestType: 'Row', row: rows }).then((response) => {
        if (response) {
          const msg = response.data?.dataset.result?.message;
          const type = response.data?.dataset.result?.type;
          if (msg) this.utilities.showAlert('alertSuccess', msg, type);
        }
      }).catch((error: string) => {
        this.utilities.showAlert('alertError', `pme::${error}`, 'error');
      }).finally(() => {
        if (gridEfetivos) gridEfetivos.datasource.loading = false;
        this.gridEditController.reload({ component });
      });
    }
  }
  
  public saveClientes({ component }: IDictionary) {
    const gridClientes = Metadata.getInstance<GridEditable>('CLIENTES_GRID');
    const gridEfetivos = Metadata.getInstance<GridEditable>('EFETIVOS_GRID');
    const filtro = Metadata.getInstance<Form>('FILTRO');
    
    if (filtro.validate() && gridClientes.isGridValid()) {
      const dados = gridEfetivos.datasource.currentRow;
      const formEstimados = Metadata.getInstance<Form>('formEfetivos');
      const rows = gridClientes.getEditedRows();
      if (formEstimados.validate() && rows.length > 0) {
        rows.forEach((item) => {
          item.CDFILCENTPME = this.appController.getCdCentral();
          item.CDFILIAL = filtro.value.UNIDADE.CDFILIAL;
          item.DTEFETCLIE = filtro.value.DTCARDIAPME;
          item.DTCARDIAPME = filtro.value.DTCARDIAPME;
          item.CDTIPOCARD = filtro.value.TIPOCARD;
          item.QTCLIESTCPME = formEstimados.value.QTCLIESTCPME;
          item.QTCOMESTCPME = formEstimados.value.QTCOMESTCPME;
          item.QTDOAESTCPME = formEstimados.value.QTDOAESTCPME;
          item.QTFUNESTCPME = formEstimados.value.QTFUNESTCPME;
          item.NRCARDPME = dados.NRCARDPME;
          item.NRCARDIAPME = dados.NRCARDIAPME;
          item.QTDOAEFECPME = dados.QTDOAEFECPME;
          item.QTCLIEFECPME = dados.QTCLIEFECPME;
          item.QTCOMEFECPME = dados.QTCOMEFECPME;
          item.QTFUNEFECPME = dados.QTFUNEFECPME;
        });
        
        if (gridClientes) gridClientes.datasource.loading = true;
        Http.post('/saveClientes', { requestType: 'DataSet', rows }).then((response) => {
          const result = response.data.dataset.result;
          this.utilities.showAlert('alertError', result.message, result.type);
          gridClientes.datasource.data = [];

          gridEfetivos.datasource.get().then(() => {
            const actualCurrentServ = gridEfetivos.datasource.data.filter((val) => val.CDSERVFILI === dados.CDSERVFILI);
            if (actualCurrentServ) gridEfetivos.datasource.currentRow = actualCurrentServ[0];
          });
        }).finally(() => {
          if (gridClientes) gridClientes.datasource.loading = false;
          this.gridEditController.reload({ component });
        });
      }
    }
  }
  
  public setFilterService() {
    const filtro = Metadata.getInstance<Form>('FILTRO');
    const gridEfetivos = Metadata.getInstance<GridEditable>('EFETIVOS_GRID');
    let nrcardpme = null;
    
    if (gridEfetivos.datasource.data.length > 1) nrcardpme = gridEfetivos.datasource.data[1].NRCARDPME;
    
    return [
      {
        name: 'CDFILCENTPME',
        operator: '=',
        value: this.appController.getCdCentral(),
      },
      {
        name: 'CDTIPOCARD',
        operator: '=',
        value: filtro.value.TIPOCARD,
      },
      {
        name: 'CDFILIAL',
        operator: '=',
        value: filtro.value.UNIDADE?.CDFILIAL,
      },
      {
        name: 'DTCARDIAPME',
        operator: '=',
        value: filtro.value.DTCARDIAPME,
      },
      {
        name: 'NRCARDPME',
        operator: '=',
        value: nrcardpme,
      },
    ];
  }

  public setFilterGridClients({ component }: IEventParam<Datasource>) {
    const formFiltro: Form = Metadata.getInstance<Form>('FILTRO');
    if (formFiltro.validate()) {
      const tipoCard = Metadata.getInstance<Select>('TIPOCARD');
      const dtTipoCard = Metadata.getInstance<Select>('DTCARDIAPME');
      const filial = Metadata.getInstance<Select>('UNIDADE');
      const gridClientes = Metadata.getInstance<GridEditable>('CLIENTES_GRID');
      if (gridClientes.editing) this.resetGrid(gridClientes);
      
      const filter = [
        {
          name: 'CDFILCENTPME',
          operator: '=',
          value: this.appController.getCdCentral(),
        },
        {
          name: 'CDFILIAL',
          operator: '=',
          value: filial.value.CDFILIAL,
        },
        {
          name: 'DTEFETCLIE',
          operator: '=',
          value: dtTipoCard.value,
        },
        {
          name: 'CDTIPOCARD',
          operator: '=',
          value: tipoCard.value,
        },
        {
          name: 'CDSERVFILI',
          operator: '=',
          value: component.currentRow.CDSERVFILI,
        },
      ];
      
      if (component.currentRow.CDSERVFILI) {
        gridClientes.datasource.filter = filter;
        gridClientes.datasource.get().then(() => {
          Metadata.getInstance<CollapseCard>('cliente-card').expanded = true;
        });
      } else {
        gridClientes.datasource.data = [];
      }
      this.setFormEstimados();
    }
  }
  
  public returnDiaSemana(data: string) {
    const semana = ['domingo', 'segunda', 'terca', 'quarta', 'quinta', 'sexta', 'sabado'];
    let result = '';
    if (data !== null) {
      const arr: IDictionary = data.split('/').reverse();
      const dateFormat = new Date(arr[0], arr[1] - 1, arr[2]);
      const dia = dateFormat.getDay();
      result = I18n.translate(`pme::${semana[dia]}`);
    }

    return result;
  }
  
  public setFormEstimados() {
    const currentRow = Metadata.getInstance<GridEditable>('EFETIVOS_GRID').datasource.currentRow;
    Metadata.getInstance<Text>('QTCLIESTCPME').text = currentRow.QTCLIESTCPME === 0 ? '0' : currentRow.QTCLIESTCPME;
    Metadata.getInstance<Text>('QTFUNESTCPME').text = currentRow.QTFUNESTCPME === 0 ? '0' : currentRow.QTFUNESTCPME;
    Metadata.getInstance<Text>('QTDOAESTCPME').text = currentRow.QTDOAESTCPME === 0 ? '0' : currentRow.QTDOAESTCPME;
    Metadata.getInstance<Text>('QTCOMESTCPME').text = currentRow.QTCOMESTCPME === 0 ? '0' : currentRow.QTCOMESTCPME;
  }
  
  public enableExport() {
    Metadata.getInstance<Button>('exportButton').disabled = false;
  }
  
  // Exportar Efetivos
  public openExportModal() {
    const gridEfetivos = Metadata.getInstance<GridEditable>('EFETIVOS_GRID');
    if (gridEfetivos.selectedRows.length !== 0) this.modalController.openModal();
  }
  
  public async createModal() {
    this.modalController.createModal('pme/medicao/modals/formExportEfetivos');
    this.modalConfigCard = await ModalService.createFromJson('pme/medicao/modals/closeButtonModalEfetivos', true);
  }

  public destroyModal() {
    this.modalController.destroyModal();
  }
  
  public cancelModal() {
    const modal = Metadata.getInstance<Modal>('formExportEfetivos');
    const unidade = modal.getChildInstance<Select>('UNIDADE');
    this.modalConfigCard.hide();
    this.modalConfigCard.destroy();
    this.modalController.closeModal();
    unidade.setValue('');
  }
  
  public setFilterUnidadeModal() {
    const gridEfetivos = Metadata.getInstance<GridEditable>('EFETIVOS_GRID');
    const modal = Metadata.getInstance<Modal>('formExportEfetivos');
    const row = gridEfetivos.selectedRows;
  
    Http.post('/buscaUnidade', { requestType: 'Row', row }).then((response) => {
      const unidadeModal = modal.getChildInstance<Select>('UNIDADE');
      const result = response.data.dataset.result.data;
      this.nrlista = response.data.dataset.result.nrlista;
      if (result.length > 0) {
        unidadeModal.datasource.updateData(result);
      } else {
        this.utilities.showAlert('alertError', 'pme::semUnidadeComServicoPrato', 'red');
      }
    });
  }
  
  public exportEfetivos({ component }: IEventParam<Button>) {
    const gridEfetivos = Metadata.getInstance<GridEditable>('EFETIVOS_GRID');
    const formExport = Metadata.getInstance<Form>('formExportEfetivos');
    const row = gridEfetivos.selectedRows;
    
    row.forEach((item) => {
      item.unidade = formExport.value.UNIDADE;
      item.nrlista = this.nrlista;
      item.DTCARDIADEST = formExport.value.DTCARDIAPME;
    });
    
    this.utilities.activeLoadingButton(component);
    Http.post('/exportEfetivos', { requestType: 'Row', row }).then(() => {
      this.utilities.showAlert('alertError', 'pme::exportadoComSucesso', 'green');
      this.cancelModal();
      gridEfetivos.selectedRows = [];
    });
  }
  
  public onInlineEdit({ component }: IEventParam<GridEditable>) {
    if (component.name === 'EFETIVOS_GRID') {
      const gridClientes = Metadata.getInstance<GridEditable>('CLIENTES_GRID');
      if (gridClientes.editing) this.resetGrid(gridClientes);
    }
    this.gridEditController.onInlineEdit({ component });
  }
  
  public clienteComponentProps = {
    component: 'ZdSelect',
    dataText: [
      {
        name: 'NRINSJURCLIE',
        mask: (Config.masks.cnpjMask as PmeMask).pattern,
      },
      'NMRAZSOCCLIE',
    ],
    formatterDataText: [
      {
        name: 'NRINSJURCLIE',
        mask: (Config.masks.cnpjMask as PmeMask).pattern,
      },
      'NMRAZSOCCLIE',
    ],
    dataValue: 'CDCLIENTE',
    dense: true,
    returnObject: true,
    datasource: {
      uniqueKey: 'CDCLIENTE',
      route: '/clienteServicoEfetivos',
      type: 'rest',
      limit: 10,
      lazyLoad: true,
    },
    validations: {
      required: {
        message: 'pme::campoObrigatorio',
      },
    },
  };
  
  // modal relatorios
  
  private async createModalRelatorios() {
    this.modalRelatorios = await ModalService.createFromJson('pme/medicao/modals/formRelatorios', true);
  }

  public closeModalRelatorios() {
    this.modalRelatorios.hide();
  }
  
  public openModalRelatorios() {
    if (!this.modalRelatorios) {
      this.createModalRelatorios().then(() => {
        this.modalRelatorios.show();
      });
    } else {
      this.modalRelatorios.show();
    }
  }
  
  public setFilterServRelatorios({ component }: IEventParam<Select>) {
    const tipoCard = Metadata.getInstance<Select>('CDTIPOCARD');
    const tpCardValue = tipoCard.value ? tipoCard.value : '';

    const filter = [
      {
        name: 'CDFILCENTPME',
        operator: '=',
        value: this.appController.getCdCentral(),
      },
      {
        name: 'CDTIPOCARD',
        operator: '=',
        value: tpCardValue,
      },
    ];
    
    component.datasource.filter = filter;
    component.datasource.get();
  }

  public setFilterUnidadeRelatorios({ component }: IEventParam<Select>) {
    const tipoCard = Metadata.getInstance<Select>('CDTIPOCARD');
    const filter = [
      {
        name: 'CDFILCENTPME',
        operator: '=',
        value: this.appController.getCdCentral(),
      },
      {
        name: 'CDTIPOCARD',
        operator: '=',
        value: tipoCard.value,
      },
    ];
    
    component.datasource.filter = filter;
    component.datasource.get();
  }
  
  public clearFieldsRelatorios({ component }: IEventParam<Select>) {
    const servicoRelatorios = Metadata.getInstance<Select>('CDSERVFILI');
    const unidadeRelatorios = Metadata.getInstance<Select>('CDFILIAL');
    
    if (component.name === 'CDTIPOCARD') {
      servicoRelatorios.setValue('');
      unidadeRelatorios.setValue('');
    } else unidadeRelatorios.setValue('');
  }
  
  public returnDiaSemanaRelatorios(data: string) {
    const semana = ['dom', 'seg', 'ter', 'qua', 'qui', 'sex', 'sab'];
    let result = '';
    if (data !== null) {
      const arr: IDictionary = data.split('/').reverse();
      const dateFormat = new Date(arr[0], arr[1] - 1, arr[2]);
      const dia = dateFormat.getDay();
      result = I18n.translate(`pme::${semana[dia]}`);
    }
    return result;
  }

  public setDefaultValuesRelatorios() {
    const dtIni = Metadata.getInstance<ZdDate>('DTINI');
    const dtFin = Metadata.getInstance<ZdDate>('DTFIN');
    const diaSemana = this.returnDiaSemanaRelatorios(this.dtProcessa);

    dtIni.value = this.dtProcessa;
    Metadata.getInstance<TextInput>('DIASEMANAINI').value = diaSemana;
    
    dtFin.value = this.dtProcessa;
    Metadata.getInstance<TextInput>('DIASEMANAFIN').value = diaSemana;
  }
  
  public validaDataRelatorios() {
    const dataProcessamento = this.dtProcessa;
    
    const fieldDiaSemanaDe = Metadata.getInstance<TextInput>('DIASEMANAINI');
    const dtTipoCardDe = Metadata.getInstance<Select>('DTINI');
    const dataComponenteDe = dtTipoCardDe.value;
    fieldDiaSemanaDe.value = this.returnDiaSemanaRelatorios(dataComponenteDe);
    
    const fieldDiaSemanaAte = Metadata.getInstance<TextInput>('DIASEMANAFIN');
    const dtTipoCardAte = Metadata.getInstance<Select>('DTFIN');
    const dataComponenteAte = dtTipoCardAte.value;
    fieldDiaSemanaAte.value = this.returnDiaSemanaRelatorios(dataComponenteAte);

    if (!this.utilities.dateIsValid(dataComponenteDe, dataProcessamento) || !this.utilities.dateIsValid(dataComponenteAte, dataProcessamento)) {
      this.utilities.showAlert('alertError', 'pme::dataMenorIgualDtProcessa', 'red');
      this.setDefaultValuesRelatorios();
    }
    
    if (this.utilities.dateIsValid(dataComponenteDe, dataProcessamento) && !this.utilities.dateIsValid(dataComponenteDe, dataComponenteAte)) {
      this.utilities.showAlert('alertError', 'pme::dataIniMaior', 'red');
      this.setDefaultValuesRelatorios();
    }
  }
  
  public validaPDF({ component }: IEventParam<Button>) {
    const form = Metadata.getInstance<Form>('RELEFETIVOS');
    if (this.utilities.centralIsValid() && form.validate()) {
      const row: IDictionary = form.value;
      
      this.setParams(row);
      if (!row.CDFILCENTPME) this.utilities.showAlert('alertError', 'pme::centralNaoInformada', 'error');
      else {
        this.reportController.callGenerateReport(component, row, 'report/efetivosRelatorio');
      }
    }
  }
  
  private setParams(row: IDictionary) {
    row.CDFILCENTPME = this.appController.getCdCentral();
    row.NMFILCENTPME = this.appController.getNmCentral();
    row.REPORT_NAME = row.REPORT.REPORT_NAME;
    row.CD_REPORT_CODE = row.REPORT.CD_REPORT_CODE;
  }
}
