import {
  Loader, Metadata, Config, IEventParam, IDictionary,
} from '@zeedhi/core';
import {
  Form, Button, Select,
} from '@zeedhi/common';
import { PmeMask } from '@/config';

export class Pme09100NutrientesCardapioController {
  public reportController = Loader.getInstance('ReportController');

  public appController = Loader.getInstance('AppController');

  public utilities = Loader.getInstance('Utilities');
  
  public modalController = Loader.getInstance('ModalController');

  public defaultReport({ component }: IEventParam<Select>) {
    component.setValue(component.datasource.data[0]);
  }

  public setFilterTpCardapio({ component }: IEventParam<Select>) {
    const conditions = [
      {
        name: 'CDFILCENTPME',
        operator: '=',
        value: this.appController.getCdCentral(),
      },
      {
        name: 'NRPASTATCARD',
        operator: '=',
        value: null,
      },
    ];
  
    component.datasource.filter = conditions;
    component.datasource.get();
  }

  public setFilterAgreg({ component }: IEventParam<Select>) {
    const conditions = [
      {
        name: 'CDFILCENTPME',
        operator: '=',
        value: this.appController.getCdCentral(),
      },
      {
        name: 'CDGRUPFILI',
        operator: '=',
        value: 'T',
      },
    ];
    
    component.datasource.filter = conditions;
    component.datasource.get();
  }

  public setFilterServ({ component }: IEventParam<Select>) {
    const cdtipoCard = Metadata.getInstance<Select>('TIPOCARD');
    const conditions = [
      {
        name: 'CDTIPOCARD',
        operator: '=',
        value: cdtipoCard.value ? cdtipoCard.value : '',
      },
      {
        name: 'CDFILCENTPME',
        operator: '=',
        value: this.appController.getCdCentral(),
      },
    ];
    
    component.datasource.filter = conditions;
    component.datasource.get();
  }

  public generateReport({ component }: IEventParam<Button>) {
    const form = Metadata.getInstance<Form>('FORM');
    if (this.utilities.centralIsValid() && this.formIsValid(form)) {
      const row: IDictionary = form.value;
      
      this.setParams(row);
      if (!row.CDFILCENTPME) this.utilities.showAlert('alertError', 'pme::centralNaoInformada', 'error');
      else {
        this.reportController.callGenerateReport(component, row, 'report/nutrientesCard');
      }
    }
  }
  
  private setParams(row: IDictionary) {
    const mask: string = (Config.masks.productMask as PmeMask).pattern;
    const paramsCard = this.utilities.getParamsCard();
    row.NRCARDPME = paramsCard.NRCARDPME;
    row.CDSERVFILI = row.SERVICO ? row.SERVICO : null;
    row.CDTIPOCARD = row.TIPOCARD ? row.TIPOCARD.CDTIPOCARD : null;
    row.NMTIPOCARD = row.TIPOCARD ? row.TIPOCARD.NMTIPOCARD : null;
    row.CDFILCENTPME = this.appController.getCdCentral();
    row.NMFILCENTPME = this.appController.getNmCentral();
    row.REPORT_NAME = row.REPORT.REPORT_NAME;
    row.CD_REPORT_CODE = row.REPORT.CD_REPORT_CODE;
    row.PRODUCTMASK = this.utilities.formatReportMask(mask);
  }

  private formIsValid(form: Form) {
    let valid = false;
    const row: IDictionary = form.value;
    const periodoDe = row.PERIODODE;
    const periodoAte = row.PERIODOATE;
    
    form.validate();
    if (periodoDe === '' || periodoAte === '') this.utilities.showAlert('alertError', 'pme::periodoObrig', 'error');
    else if (form.validate()) {
      if (this.utilities.dateIsValid(periodoDe, periodoAte)) valid = true;
      else this.utilities.showAlert('alertError', 'pme::dataIniMaior', 'error');
    }
    return valid;
  }

  public openModalSearch() {
    const tipoCard = Metadata.getInstance<Select>('TIPOCARD');
    if (tipoCard.value) {
      this.modalController.openModal();
      this.utilities.setCdTipoCard(tipoCard.value.CDTIPOCARD);
    } else {
      this.utilities.showAlert('alertError', 'pme::tipocardNaoSelecionado', 'warning');
    }
  }

  public async createPeriodoModal() {
    this.modalController.createModal('modals/gridPeriodo');
  }

  public destroyPeriodoModal() {
    this.modalController.destroyModal();
  }
}
